==> libreoffice-l10n_4.4.3~rc2.orig.tar.xz: libreoffice-4.4.3~rc2/oox/source/drawingml/chart/plotareamodel.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include "drawingml/chart/plotareamodel.hxx"

namespace oox {
namespace drawingml {
namespace chart {

View3DModel::View3DModel() :
    mnDepthPercent( 100 ),
    mnPerspective( 30 ),
    mbRightAngled( false )
{
}

View3DModel::~View3DModel()
{
}

WallFloorModel::WallFloorModel()
{
}

WallFloorModel::~WallFloorModel()
{
}

DataTableModel::DataTableModel() :
        mbShowHBorder(false),
        mbShowVBorder(false),
        mbShowOutline(false)
{
}

DataTableModel::~DataTableModel()
{
}

PlotAreaModel::PlotAreaModel()
{
}

PlotAreaModel::~PlotAreaModel()
{
}

} // namespace chart
} // namespace drawingml
} // namespace oox

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice-l10n_5.1.2.orig.tar.xz: libreoffice-5.1.2/oox/source/drawingml/chart/plotareamodel.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include "drawingml/chart/plotareamodel.hxx"

namespace oox {
namespace drawingml {
namespace chart {

View3DModel::View3DModel(bool bMSO2007Doc) :
    mnDepthPercent( 100 ),
    mnPerspective( 30 ),
    mbRightAngled( !bMSO2007Doc )
{
}

View3DModel::~View3DModel()
{
}

WallFloorModel::WallFloorModel()
{
}

WallFloorModel::~WallFloorModel()
{
}

DataTableModel::DataTableModel() :
        mbShowHBorder(false),
        mbShowVBorder(false),
        mbShowOutline(false)
{
}

DataTableModel::~DataTableModel()
{
}

PlotAreaModel::PlotAreaModel()
{
}

PlotAreaModel::~PlotAreaModel()
{
}

} // namespace chart
} // namespace drawingml
} // namespace oox

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
